#### generate, start and stop multiple tomcat for Convertigo ####
## This script must be in a directory with a configured tomcat+convertigo (may /opt/convertigo) and run by a user with a write access (but not root)
## The file server.xml comming with control.sh must be in this folder 

DIR=`( cd -P $(dirname $0); pwd)`
WORKERS=${DIR}/workers
CEMS_WORKSPACE=${DIR}/workspace
BASE_HTTP=28080
BASE_AJP=28380
BASE_SHUTDOWN=28280
BASE_SSL=28180
export DISPLAY=:3
export CATALINA_HOME=${DIR}/tomcat
export JRE_HOME=${DIR}/jre
export JAVA_OPTS=" -Xmx512m -Djava.net.preferIPv4Stack=true"
# export JAVA_OPTS="${JAVA_OPTS} -Dconvertigo_global_symbols=" ## OPTION ## uncomment this line to handle global symbols
chmod u+x ${CATALINA_HOME}/bin/*.sh
generate()
{
  if [ $1 -ge 0 ] && [ $1 -le 99 ] ; then
    for WORKER in ${WORKERS}/on_* ; do
      if [ -d ${WORKER} ] ; then
        echo "removing ${WORKER}"
        rm -rf ${WORKER}
      fi
    done
    for i in $(seq 0 $(($1 - 1))) ; do
      WORKER=${WORKERS}/on_$(printf "%02d" $i)
      echo "copying ${WORKER}"
      cp -r ${WORKERS}/worker_base ${WORKER}
    done
  else
    echo "Must be between 0 and 99"
  fi
}
startup()
{
  for WORKER in ${WORKERS}/on_* ; do
    if [ -d ${WORKER} ] ; then
      NUM=${WORKER##*/on_}
      PORT_HTTP=$(( $BASE_HTTP + $NUM ))
      PORT_SSL=$(( $BASE_SSL + $NUM ))
      PORT_AJP=$(( $BASE_AJP + $NUM ))
      PORT_SHUTDOWN=$(( $BASE_SHUTDOWN + $NUM ))
      sed -e s/PORT_HTTP/${PORT_HTTP}/g -e s/PORT_SSL/${PORT_SSL}/g  -e s/PORT_AJP/${PORT_AJP}/g -e s/PORT_SHUTDOWN/${PORT_SHUTDOWN}/g ${WORKERS}/worker_base/conf/server.xml > ${WORKER}/conf/server.xml
      echo "Starting the worker ${NUM} : HTTP ${PORT_HTTP}, HTTPS ${PORT_SSL}, AJP ${PORT_AJP}"
      CEMS_WORKSPACE=${WORKERS}/wp_${NUM} ## OPTION ## comment this line to share the workspace
      mkdir ${CEMS_WORKSPACE}
      JAVA_OPTS="${JAVA_OPTS} -Dconvertigo.cems.user_workspace_path=${CEMS_WORKSPACE}" CATALINA_BASE=${WORKER} ${CATALINA_HOME}/bin/startup.sh
      waitportup ${PORT_SHUTDOWN} 120
    fi
  done
}
shutdown()
{
  for WORKER in ${WORKERS}/on_* ; do
    if [ -d ${WORKER} ] ; then
      PORT_SHUTDOWN=$(( $BASE_SHUTDOWN + ${WORKER##*/on_} ))
      CATALINA_BASE=${WORKER} ${CATALINA_HOME}/bin/shutdown.sh
      waitportdown ${PORT_SHUTDOWN} 120
    fi
  done
}
waitportup()
{
  cpt=$2
  while !(netstat -lnt | grep :$1 > /dev/null) && [ $cpt -gt 0 ] ; do
    sleep 1
    cpt=$(($cpt-1))
  done
  if [ $cpt -eq 0 ]; then
    echo "Timeout for $1, still not ok"
  fi
}
waitportdown()
{
  cpt=$2
  while (netstat -lnt | grep :$1 > /dev/null) && [ $cpt -gt 0 ] ; do
    sleep 1
    cpt=$(($cpt-1))
  done
  if [ $cpt -eq 0 ]; then
    echo "Timeout for $1, still not ok"
  fi
}
case "$1" in
generate)
  if [ x != x$2 ] ; then
    generate $2
  else
    echo "Missing argument"
  fi
  ;;
startup)
  startup
  ;;
shutdown)
  shutdown
  ;;
*)
  echo "Usage: $0 {startup|shutdown|generate n}"
  exit 1
esac
exit 0

